## 2020-科技新聞
### TechOrange
### 不只蘋果、高通，美國國防部也需要台積電的晶片！
| VIEW MORE »
### TechOrange 【布局全球太空產業供應鏈】嘉義 21 歲年輕人打造「球型馬達」，讓微型衛星減重省電 20％
| VIEW MORE »
|  | ### TechOrange 工程師來破解！Google 將 I/O 開發者大會日期藏在 7 大謎題裡
| VIEW MORE »
### TechOrange Coinbase 員工交換「NFT 婚戒」，在區塊鏈上成為夫妻！
| VIEW MORE »
|  | ### TechOrange 半世紀來最嚴重旱災！紐時關注台灣半導體業「與農民爭水」
| VIEW MORE »
### TechOrange 【省水大挑戰】繼水下資料中心後，微軟這次要把伺服器放到「按摩浴缸」裡
| VIEW MORE »
|  | ### TechOrange 找不到鑰匙和眼鏡的人有福了，蘋果開放「尋找」功能給第三方
| VIEW MORE »
### TechOrange 【抗老要從年輕做起】這 3 個習慣能幫你凍齡，其中一個關鍵就在「牙齒」
| VIEW MORE »
|  | ### TechOrange 召集開發者線上響應，4 月《TechOrange》獨家破解 2021 年 4 大 Azure 技術關鍵
| VIEW MORE »
### TechOrange AI 專案常陣亡？NVIDIA 合作夥伴麗臺科技：企業缺乏「維運能力」是主因
| VIEW MORE »
|  | ### TechOrange 1 滴水用 4 次！台電電廠今天啟用「微水力」來提升發電效率
| VIEW MORE »
### TechOrange 為什麼汽車、飛機有安全帶，但火車、高鐵沒有？
| VIEW MORE »
|  | ### TechOrange 【猴子比你還會】馬斯克推出腦波控制器，讓猴子用「念力」玩電玩
| VIEW MORE »
### TechOrange 沒資源、缺人脈該如何競標？前 eBay 營運長給新創的 5 大談判要點
| VIEW MORE »
|  | ### TechOrange 【未來人人是猛毒？】日本研究：人類也有毒液系統！基因顯示具產生毒液的潛力
| VIEW MORE »
### TechOrange 顛覆近 50 年來的物理理論？科學家發現未知粒子的存在證據：g 因子偏差
| VIEW MORE »
|  | ### TechOrange 機器學習博士數量激增！那麼沒讀 ML 博班的人，找工作難度會翻 N 倍嗎？
| VIEW MORE »
### TechOrange 【成長中的 PropTech】美國新創用演算法、大數據賣房，還給菁英業務員 9 成利潤！
| VIEW MORE »
|  | ### TechOrange 【取之於台用之於台】台積電、世芯晶片助中國製飛彈？王美花：未涉軍用
| VIEW MORE »
### TechOrange 哈佛把紙揉成一團，發現摺痕暗藏的「對數規則」
| VIEW MORE »
|  | ### TechOrange 成功的人都怎麼想？馬斯克、貝佐斯用這個關鍵思維面對失敗
| VIEW MORE »
### TechOrange 工程師破解 M1 MacBook 容量限制，DIY 升級 1TB SSD+16G RAM！
| VIEW MORE »
|  | ### TechOrange 石虎也當 Vtuber？ 特生中心攜手虛擬偶像「瀕臨絕種團」推廣保育
| VIEW MORE »
### TechOrange 新物種恐龍有譜？Neuralink 共同創辦人：我們隨時可蓋侏儸紀公園
| VIEW MORE »
|  | ### TechOrange 西雅圖曾因依賴波音而陷入困境，矽谷是否也會面臨相同困局？
| VIEW MORE »
### iThome
### iThome AI Labs推出臺灣首個聯合學習平臺服務，提出4階段FL流程來加速企業導入
| VIEW MORE »
|  | ### iThome 【靠ML協作平臺加速AI落地】Line如何用MLOps重構AI開發流程
| VIEW MORE »
### iThome Arm推出v9架構，主打機密運算防護應用
| VIEW MORE »
|  | ### iThome 一周大事：Armv9架構主打機密運算新應用。Google不必賠償甲骨文天價Java API侵權費
| VIEW MORE »
### iThome 微軟開源C#語言標準制定工作
| VIEW MORE »
|  | ### iThome 資安一周第140期：臉書5億筆用戶個資流落於駭客論壇。美國政府要求聯邦政府機關清查ProxyLogon漏洞
| VIEW MORE »
### iThome Twitch將封鎖在服務外違反行為準則的用戶
| VIEW MORE »
|  | ### iThome 報導：Twitter曾企圖以40億美元買下Clubhouse，雙方破局收場
| VIEW MORE »
### iThome 美國把7個中國超級電腦相關組織列入黑名單
| VIEW MORE »
|  | ### iThome 三星發表同時支援BLE與UWB的物件追蹤器SmartTag+
| VIEW MORE »
### iThome Asteelflash Group遭REvil勒索軟體攻擊，日月光集團公告說明環旭電子營運不受影響
| VIEW MORE »
|  | ### iThome 臺灣資安研究之光！戴夫寇爾勇奪Pwn2Own冠軍，臺灣首度獲獎就拿下6百萬獎金
| VIEW MORE »
### iThome 駭客賤賣價值近4千萬美元的禮物卡資料，疑自禮物卡交易網站竊得
| VIEW MORE »
|  | ### iThome 微軟釋出AI網路攻防模擬工具
| VIEW MORE »
### iThome 網格生成演算
| VIEW MORE »
|  | ### iThome 臉書：資料外洩為網頁抓取，非被駭
| VIEW MORE »
### iThome 4月Android更新讓Pixel 5效能大增逾30%
| VIEW MORE »
|  | ### iThome 國產AI新創InfuseAI靠MLOps產品A輪募資430萬美元，今年聚焦模型監控，Q2將推新外掛工具平臺
| VIEW MORE »
### iThome 蘋果iOS 14.5將啟用程式透明化追蹤功能，提供可保護隱私的廣告測量機制
| VIEW MORE »
|  | ### iThome Google開源低位元率音訊編解碼器Lyra
| VIEW MORE »
### iThome T-Mobile推出5G家用網路服務
| VIEW MORE »
|  | ### iThome 網路釣魚偽裝成LinkedIn的職缺，散播木馬程式
| VIEW MORE »
### iThome 北韓駭客Lazarus利用新的後門程式對南非貨運公司下手
| VIEW MORE »
|  | ### iThome Signal開始測試加密貨幣支付系統
| VIEW MORE »
### iThome 思科修補SD-WAN vManage的遠端程式攻擊漏洞
| VIEW MORE »
|  | ### iThome 俄國當年如何用網戰讓川普勝選
| VIEW MORE »
### iThome 臺灣IBM揭露今年在臺發展策略，鎖定服務容器化、資料治理等新需求
| VIEW MORE »
|  | ### iThome 微軟Azure資料中心將測試浸沒式伺服器冷卻技術
| VIEW MORE »
### iThome 行動程式如何追蹤你？蘋果《A Day in the Life of Your Data》揭面紗
| VIEW MORE »
|  | ### iThome AWS程式碼導師服務Amazon CodeGuru大幅降價
| VIEW MORE »
### iThome 駭客搜刮並兜售5億LinkedIn用戶資料
| VIEW MORE »
|  | ### iThome 大膽試新技術不怕砍掉重來， 愛料理玩出不一樣的邊緣運算新模式
| VIEW MORE »
### iThome Verizon召回250萬個有著火之虞的行動熱點
| VIEW MORE »
|  | ### iThome 補了沒？Cring勒索軟體現在對Fortinet OS漏洞發動攻擊
| VIEW MORE »
### iThome Fintech周報第178期：中國信託銀行聯手程澈科技推新型態信貸商品，引用社群銷售交易數據建立社群賣家信評模型
| VIEW MORE »
|  | ### iThome 惡意程式冒充免費Netflix程式，藉WhatsApp自動回覆功能散布
| VIEW MORE »
### iThome Line臺灣AI團隊現身說法，如何從零開始實作MLOps
| VIEW MORE »
|  | ### iThome 今年Google I/O將於5月18日在線上舉行
| VIEW MORE »
### iThome SAP警告駭客正在攻擊本地部署系統已知漏洞
| VIEW MORE »
|  | ### iThome Discord與Slack等協作平臺日益成為駭客散布惡意程式的管道
| VIEW MORE »
### iThome 2020年起的網釣工具新趨勢，Telegram機器人崛起
| VIEW MORE »
|  | ### iThome IBM推COBOL上雲端
| VIEW MORE »
### iThome 兼具專業繪圖效能與攜行，Dell最輕15吋筆電工作站新登場
| VIEW MORE »
|  | ### iThome P&G傳以中國技術繞過蘋果隱私政策
| VIEW MORE »
### iThome 蘋果Find My功能正式支援第三方產品
| VIEW MORE »
|  | ### iThome Cloud周報第103期：微軟Azure、D365中斷原因找到了，因暴增查詢湧入DNS曝程式碼缺陷
| VIEW MORE »
### iThome VMware整合VCF和Tanzu兩大產品線，推出跨多雲授權新訂閱服務Cloud Universal
| VIEW MORE »
|  | ### iThome 跟Line學MLOps
| VIEW MORE »
### iThome 導入11代Core處理器，聯想X1 Carbon商用筆電邁入第9代
| VIEW MORE »
|  | ### iThome 微星跨足商用二合一筆電，率先支援Wi-Fi 6E無線網路新規格
| VIEW MORE »
### iThome Line AI開發的關鍵基礎架構──ML Universe關鍵功能大公開
| VIEW MORE »
|  | ### iThome 加密貨幣交易平臺Coinbase今年首季獲利超越2020全年表現
| VIEW MORE »
### iThome 微軟持續提升NuGet套件還原效能
| VIEW MORE »
|  | ### iThome AI趨勢周報第164期：交通部未來4年AI重點：打造智慧交通數位神經中樞
| VIEW MORE »
### iThome 新仇舊恨？Google、Alphabet財務系統將從甲骨文轉為SAP
| VIEW MORE »
|  | ### iThome Have I Been Pwned開放外界以電話號碼查詢是否被臉書外洩個資
| VIEW MORE »
### iThome Amazon創辦人貝佐斯蟬聯全球首富，Tesla創辦人馬斯克緊追在後
| VIEW MORE »
|  | ### iThome 微軟小畫家、剪貼工具在Microsoft Store上架
| VIEW MORE »
### iThome 趨勢科技聯手165防詐騙專線，公布2021第一季三大熱門詐騙手法
| VIEW MORE »
|  | ### iThome 歐盟將調查臉書5.3億用戶資料外洩
| VIEW MORE »
### Business Next
### Business Next 美感門市設計！日本電信龍頭打造咖啡廳、公園感體驗空間，連員工制服也大改造
| VIEW MORE »
|  | ### Business Next AZ疫苗擴大施打、歐盟證實可能與血栓有關？疫苗資訊懶人包一次看
| VIEW MORE »
### Business Next 4月職缺突破82萬創新高、技術人員最缺！新鮮人平均6個月就想換工作
| VIEW MORE »
|  | ### Business Next 靈感來自寶可夢人潮！全家App新玩法翻轉零售思維，2個月吸逾20億點數兌換
| VIEW MORE »
### Business Next 大立光首季獲利衰2成！林恩平宣告：缺料打擊4、5月也不會好，車用滿足一條件才加入
| VIEW MORE »
|  | ### Business Next 全面開放！E3 2021電玩展拍板線上舉行，大廠遊戲新作全都免費體驗
| VIEW MORE »
### Business Next 激勵讀者當「國王」！Readmoo西洋棋分級制，晉級競賽讓總閱讀時間翻2倍
| VIEW MORE »
|  | ### Business Next 「疫苗假」有譜、接種一劑最多可請2天假？勞動部：不得視為曠職或扣全勤獎金
| VIEW MORE »
### Business Next 特斯拉也在做！高宇能源打造居家儲能系統，前進日本助用戶「大省一波」電力及電費！
| VIEW MORE »
|  | ### Business Next 4月30日放假，連假3天的小確幸！不上班，原因一次弄懂
| VIEW MORE »
### Business Next 全台99萬股民持有ETF，年輕人最愛買！為何說它其實也算「主動投資」？
| VIEW MORE »
|  | ### Business Next 國航首架空巴A320neo亮相！虎航喜迎新機，全面解封前如何找財源？
| VIEW MORE »
### Business Next 進擊的巨人139話出爐、出版社網站一度癱瘓！連載12年、抓住鐵粉的魅力在哪？
| VIEW MORE »
|  | ### Business Next Google I/O將於5月中強勢回歸！免費開放全球開發者參與、新版隱私政策受關注
| VIEW MORE »
### Business Next 波士頓動力放下跳舞機器狗，第一個商業應用為何是超接地氣的「搬運工」？
| VIEW MORE »
|  | ### Business Next 小鵬汽車也要自製專用晶片、年底量產！造車新星們為何都向特斯拉「抄作業」？
| VIEW MORE »
### Business Next 進擊的巨人139話完結，作者揭創作心法！諫山創：想成功要夠變態
| VIEW MORE »
|  | ### Business Next 特斯拉大改款Model S、Model X連一台都沒交車！傳量產卡關出貨推遲數月
| VIEW MORE »
### Business Next 用OMO模式創造消費新軌跡，迎接後疫情商業時代
| VIEW MORE »
|  | ### Business Next 24小時「印」出一棟豪宅！3D列印社區正席捲全球，下一步要飛向月球蓋房？
| VIEW MORE »
### Business Next 美廉社攜手Tomod's推藥妝複合店、進軍外送！現代柑仔店如何吸引年輕客？
| VIEW MORE »
|  | ### Business Next 東元家變內幕！黃茂雄：兒子對我下跪道歉，以為是求和、沒想到是求戰
| VIEW MORE »
### Business Next Intel、Arm、AMD搶占資料中心先機！微軟攜緯穎造全球首座液冷基地、鴻海大動作爭FANNG訂單
| VIEW MORE »
|  | ### Business Next Facebook陷個資外洩陰霾！5.33億筆個資遭「免費」看，3招自驗帳號是否遭了殃
| VIEW MORE »
### Business Next 果粉哭哭！蘋果關鍵零組件短缺，MacBook、iPad新品生產進度落後、上市恐延期
| VIEW MORE »
|  | ### Business Next 助小銀行對抗華爾街巨頭！這家數位服務商市占僅1%，為何有底氣敢申請IPO？
| VIEW MORE »
### Business Next 攜手施耐德、三菱、士林電機三家大廠！宏于首推智慧配電盤，有哪些創新？
| VIEW MORE »
|  | ### Business Next 台灣是醫療面板供應大國，公衛電腦卻是小咖！友達攜手凌華攻進白色巨塔
| VIEW MORE »
### Business Next 中芯大力留住梁孟松，傳替他加薪4.5倍、送9千萬豪宅！能一解宿怨嗎？
| VIEW MORE »
|  | ### Business Next 最強螃蟹！瑞昱一封信告知客戶交期32週起跳，研華Q2喊漲，一張表看懂這波缺貨有多兇
| VIEW MORE »
### Business Next Sony電動車上路測試，下一步有望攜手鴻海！如何圓彼此的造車夢？
| VIEW MORE »
|  | ### Business Next NFT與加密藝術，區塊鏈應用的異端興起
| VIEW MORE »
### Business Next 台積電Q1達財測99%高標！ 晶片荒還看不到盡頭，護國神山年底前三度漲價？
| VIEW MORE »
|  | ### Business Next 把惡夢換下來！張淑芬助太魯閣號救難人員換新制服，要幫助家屬走出傷痛
| VIEW MORE »
### Business Next 百貨龍頭跨界Outlet！新光三越SKM Park插旗高雄，為何敢叫陣「南霸天」義大世界？
| VIEW MORE »
|  | ### Business Next 新創投資破3.5兆創紀錄，銀彈卻集中在幾隻獨角獸！一張圖看懂今年Q1創投趨勢
| VIEW MORE »
### Business Next Google開課程，你也可以上！結業有望進入130間大企業，巨頭認證哪5種專業人才？
| VIEW MORE »
|  | ### Business Next 半世紀最嚴重台鐵事故，各界善款累計破4億元！如何捐款、何時通車一次看
| VIEW MORE »
### INSIDE
### 美國太空總署在清查國際太空站上的微生物時，有時甚至還會發現新物種！這些生命力頑強的細菌，很可能會幫上人類進行宇宙長途旅行的忙。
| VIEW MORE »
### INSIDE 「數位轉型普拉斯」代表進階升級的數位轉型議題，INSIDE 將從 AIoT、5G、資安、智慧生活、雲端科技 5 大接觸點，剖析台灣產業轉型的最佳策略。
| VIEW MORE »
|  | ### INSIDE 美國加速器 Techstars 在全球投資並扶植超過 2,000 間新創公司，今年首次與日本內閣府、日本貿易振興機構（JETRO）及經濟產業省合作，進行為期十週的「新創培育計畫（Techstars Founder Catalyst Japan）」，藉此加深日本新創產業與國際的連結。
| VIEW MORE »
### INSIDE Cookieless 年代正式來臨，阿物科技舉辦 MarTech Asia 2021 論壇邀請包含行銷科技之父 Soctt Brinker以及美、台，日三國重量級講者們針對六大主題聚探討行銷科技最新趨勢與作法。
| VIEW MORE »
|  | ### INSIDE 小資開店安裝安全監控設備免花大錢！凱擘大寬頻提供 HomeSecurity AI 店家防護，每個月不到一千元，就能輕鬆掌握您的店面安全。
| VIEW MORE »
### INSIDE 沙丘上鮮豔的色彩對應出不同的表面溫度。例如像是珊瑚礁一樣的橘色，代表比較溫暖的地表狀態，而左上角像是夢幻積雪的藍色，則相較低溫。
| VIEW MORE »
|  | ### INSIDE 公告指出，阿里巴巴集團排除、限制了中國境內網路零售平台服務市場的競爭，妨礙商品服務和資源要素自由流通，影響平台經濟創新發展，侵害平台內商家合法權益，損害消費者利益，已構成違反「反壟斷法」。
| VIEW MORE »
### INSIDE P&G 是全球最大廣告客戶之一，這次為應對蘋果新規以達到廣告投放目的，參與了中國的廣告技術測試。據知情人士透露，P&G 是參與此技術測試中最大型公司。
| VIEW MORE »
|  | ### INSIDE 打造智慧安心生活，有什麼值得考慮的解決方案？凱擘大寬頻近期為「家用無線網路」和「居家安全監控」兩大智慧家庭應用主軸，提供完善的生活提案。
| VIEW MORE »
### INSIDE MarTech 科技服務商阿物科技未來將以 AI 科技服務商的全新面貌，鎖定新零售產業，協助客戶企業善用 AI 前瞻技術及 MarTech 解決方案，搶攻虛實整合龐大新商機。
| VIEW MORE »
|  | ### INSIDE 金管會協助 NCC 調查富邦集團董事長蔡明忠，主要是因為與近期有線電視 TBC 案投資事件有關。
| VIEW MORE »
### INSIDE 全球電子產品需求激增導致半導體供應吃緊時，台灣供水出現變數，科技界依賴台灣與全球晶圓代工龍頭台積電引發的憂慮，可能更難減輕。
| VIEW MORE »
|  | ### INSIDE 不過蝦皮目前僅送蔬菜、水果與雞蛋，而且由廠商直送，時間是「上午下單、傍晚送到」或「下午下單、隔天送達」，跟對手的 20 分鐘或 1 小時到貨相差很大。
| VIEW MORE »
### INSIDE 從零到一的創業大冒險，誠如蘇格登威士忌一連串的製酒過程。帶上蘇格登 12 年單一麥芽威士忌，與新芽網路 CEO 劉邦彥一同回顧創業奇蹟，以及他學到的三件事。
| VIEW MORE »
|  | ### INSIDE 根據官方「友善地圖」功能花了半年開發，透過鮮食庫存動態系統，並結合消費者手機中的即時定位功能，即可一鍵查詢各店友善食光的商品與數量！
| VIEW MORE »
### INSIDE 這隻 9 歲的雄性獼猴，牠的大腦每一冊都植有晶片，在鏡頭前轉動搖桿玩「Mind Pong」遊戲，但事實上該搖桿已經拔掉電源，真正操作浮標移動的力量來自牠的大腦。
| VIEW MORE »
|  | ### INSIDE 不只提供家用網路服務，台灣大寬頻領先同業跳脫框架，不斷轉型革新，結合數位與科技技術提供更多元的網路應用服務，包含 1G 光纖上網＋Wi-Fi 6＋Mesh 的高規格居家連網環境建置，還有網路延伸應用的 HomeSecurity AI 居家防護與 HomeSecurity AI 店家防護安全監控服務，更是家庭與事業的絕佳智慧幫手。
| VIEW MORE »
### INSIDE 近期「護國神山」成為大家琅琅上口的話題，談的不是買了幾張股票，而是台灣在疫情之後所展現的產業韌性及研發實力。事實上，台灣的軟體實力也很強勁，近期切入雲端事業的 iKala，立志打造另一座「雲端群山」。
| VIEW MORE »
|  | ### INSIDE Google Chrome 即將淘汰幫助廣告主的工具—— Cookie ，它的離去將再一次地影響數位廣告產業。
| VIEW MORE »
### INSIDE 這間位於浙江嘉興市 Beyond Meat 首個中國工廠，同時也成為該企業首個美國以外的端到端（end-to-end）生產工廠。
| VIEW MORE »
|  | ### INSIDE Sony 影業確定與 Netflix 合作了！從 2022 年起，美國地區 Netflix 可使用旗下電影內容，包含預定 2020 年上映的《蜘蛛人：無家日》 （Spider-Man: No Way Home）。
| VIEW MORE »
### INSIDE 川普任內對企業所得的優惠稅率 21% ，拜登上任要漲到 28%，來擴大美國國內基礎建設。
| VIEW MORE »
|  | ### INSIDE 在國外推動行之有年的潔淨標章（Clean Label），在疫情趨使之下預估至2024年，市場估計將達到511.4億美元，以國外各大食品品牌的因應之道為例，作為台灣新創企業的發展利基。
| VIEW MORE »
### INSIDE LG 手機在美國市場拿下 9% 市占、排名第三。
| VIEW MORE »
|  | ### INSIDE 這次修法草案有非常多跟網路有關！例如大賣場播放 YouTube 網路影片會變成「再公開傳達」，網路上刊登販售盜版音樂、遊戲，也會直接處二年以下有期徒刑以及民事責任了！
| VIEW MORE »
### INSIDE 最新調查顯示，美國股市目前有 15% 的投資者是 2020 年才進場，散戶對市場的參與度大增。
| VIEW MORE »
|  | ### INSIDE 為了客觀評鑑鑽石最重要的光芒和鑽石歷程，以新科技研發出 SARINE LIGHT 光芒評鑑系統和 Diamond Journey 鑽石歷程回溯系統，目前全球只有銀座白石導入。
| VIEW MORE »
### INSIDE 馬斯克 8 日透過 Twitter 表示，感謝供應商為特斯拉提供關鍵零組件！
| VIEW MORE »
|  | ### INSIDE 儘管美國疫苗已經開打，而 Uber 也對外聲稱叫車需求正在回升，但實際情況仍要考量日常生活何時重回正軌。
| VIEW MORE »
### INSIDE 用區塊鏈來認證藝術品，沒有實體還是有「蒐藏」價值？
| VIEW MORE »
|  | ### INSIDE 一般的 ETF，平均要花 3 年才能吸引 1 億美元流入。
| VIEW MORE »
### INSIDE 增加原因為新冠肺炎帶來的旅遊禁令，以及 2020 美國大選時期不安局勢的考量，讓去年祖克伯的人身安全風險增加，於是乎增加安全方面的成本，加強戒備。
| VIEW MORE »
|  | ### INSIDE 我們的國旗正式出現在推特官方帳號的推文當中，跟泰國、香港、緬甸一起，獨缺印度。
| VIEW MORE »
### INSIDE 高盛分析師預估，拜登的企業稅計劃恐將使標準普爾 500 指數企業明年的 EPS 減少 9%。
| VIEW MORE »
|  | ### INSIDE 疫情下引爆各家串流業者大戰的同時，在美國，這些內容要到達消費者眼中，大多還得經過一支和 USB 隨身碟大小差不多的電視棒。而 Roku 就這樣默默成為串流大戰第二回合的隱形冠軍。
| VIEW MORE »
### INSIDE 除了資本支出的競逐、地緣政治的影響等因素之外，若從產業趨勢的角度切入，這兩家半導體雙雄的大動作，其實可以跟矽智財大廠 ARM（安謀）推出 v9 架構搭配來看
| VIEW MORE »
|  | ### INSIDE 第20屆「新創事業獎」報名時間現在起至 110 年 6 月 1 日（二） 17:00 止，歡迎創業家們踴躍報名參與。
| VIEW MORE »
### INSIDE 經濟部工業局以「企業出題，人才實戰，以戰代訓」創新兼具實務的作法，期以發展專業人才帶動產業布局與技術升級。 5G+ 產業新星甄選已經開跑，即日起開放大三到碩博士在學生與應屆畢業生報名至 4 月 15 日止。
| VIEW MORE »
|  | ### INSIDE 由沒幾天後，這台 Starship SN11 在試飛時於再降落期間爆炸，NASA 已經派發言人說像 SpaceX 這樣的承包商應有足夠的保護機密措施。
| VIEW MORE »
### INSIDE 分析師指出，Nokia 品牌手機近年主攻平價款和 B2B 市場的手機。
| VIEW MORE »
|  | ### INSIDE 在生活、商業模式因疫情產生巨變，混合辦公、遠距會議、線上教育等場景不僅已成為「新常態」，更是企業在後疫情時代下創新的重要根基。近期成為國際視訊通訊平台Zoom官方代理商的第一線集團（DYXnet Group），引領企業輕鬆打造靈活遠距辦公室。
| VIEW MORE »
### INSIDE 這 20 台醫用觸控電腦 MLC-8 提供易操作、易清潔的一體成型機殼，可降低醫療照護相關感染機率。
| VIEW MORE »
|  | ### INSIDE 電商平台已經不只是購物管道，更成為消費者在選購前，蒐集資訊的媒體平台。透過蝦皮 X Facebook 廣告，品牌賣家們藉由經營電商，並結合社群、影音等各類數位媒體，即便處在銷售淡季，也能透過電商通路接觸新客群、衝出新業績。
| VIEW MORE »
### INSIDE 走過了充滿不確定性的 2020，來到充滿新氣象的 2021，究竟該儲備能量還是朝向夢想勇往直前？全新改款的 SYM VEGA 125 特別邀請到金曲新人王：持修，為年輕發聲、也為持續付出熱情與任性的年輕人加油打氣。
| VIEW MORE »
|  | ### INSIDE 國發會亞洲・矽谷計畫執行中心幫助「台北花市」、「阿瘦皮鞋」兩家企業數位轉型，成功導入 AI 應用以提升企業產能及附加價值。
| VIEW MORE »